/**
 * This JavaScript file contains code that will be called upon the start of 
 * Kobold Adventure. It includes definitions of critical global objects, which
 * may be referred to throughout the project. The initialization of the global
 * object should occur as soon as possible.
 */

function Global() {
    // PRIVATE MEMBERS \\       var private = "test";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";
    this.ui = new UiController();
    this.sceneLoader = new SceneLoader();
    this.saveManager = new SaveManager();
    this.parser = new KoboldParser();
    this.settings = new Settings();

    // The id of the current scene. Needed for saving.
    this.currentScene = "";
    // The name of the current scene.
    this.currentSceneName = "";
    // The folder of the current scene.
    this.currentSceneFolder = "";
    
    // The most important character around: the kobold.
    this.kobold = new Character();

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Initializes all global objects.
     */
    this.init = function () {
        this.ui.init();
    };
    
    /**
     * Displays an error message.
     * Should only be done in terminal cases.
     * @param {string} errorMessage The error message to display.
     */
    this.error = function (errorMessage) {
        alert(errorMessage);
    };

    /**
     * Ends the current scene, resetting the scroll level to zero.
     */
    this.sceneEnd = function () {
        this.ui.sceneScroll = 0;
    };
}

var global = new Global();
