/**
 * The LinenBra class represents a simple linen bra that can be worn by the kobold.
 */
function LinenBra() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "Linen Bra";
    var itemDescription = "A simple, yet effective bra.";
    var baseValue = 8;
    var offensiveValue = 0;
    var defensiveValue = 0;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.LINENBRA;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.GEAR;
    // GEAR-REQUIRED slot-enum.
    this.slot = SlotEnum.BRA;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        var toReturn = caps ? itemName : itemName.toLowerCase();
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        return itemDescription;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        return baseValue;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        return "width: 190px;";
    };

    /**
     * GEAR-REQUIRED function.
     * Calculates and returns the offensive value of this piece of gear.
     * @returns {int} The offensive value of this piece of gear.
     */
    this.offence = function () {
        return offensiveValue;
    };

    /**
     * GEAR-REQUIRED function.
     * Calculates and returns the defensive value of this piece of gear.
     * @returns {int} The defensive value of this piece of gear.
     */
    this.defence = function () {
        return defensiveValue;
    };

    /**
     * BRA-required function.
     * Returns true if the bra is skimpy, and false otherwise.
     * @returns {boolean} True if the bra is skimpy, and false otherwise.
     */
    this.skimpy = function () {
        return false;
    };

    /**
     * BRA-required function.
     * Returns true if the bra can be torn, and false otherwise.
     * @returns {boolean} True if the bra can be torn, and false otherwise.
     */
    this.canBeTorn = function () {
        return true;
    };

    /**
     * BRA-required function.
     * Returns true if the bra is a mismatch for the kobold's current gender.
     * @returns {boolean} True if the bra is a mismatch for the kobold's current gender, false otherwise.
     */
    this.wrongGender = function () {
        return global.kobold.body.getBaseGender() !== GenderEnum.FEMALE; // Bras are for girls.
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {ChestWrap-stripped} bra A ChestWrap object, stripped of private members and all functions.
     */
    this.load = function (bra) {
        
    };
}
