/**
 * Bite section of the unknown scene.
 * @param {ForestController} controller The forest controller.
 */
function ForestUnknownBiteContinue(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = `runContinueButton`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            For the second time today, you find yourself running for your life.
                            You don't know whether or not the plant is giving chase, but fright and adrenaline combined make you [b]keep running[/b] without looking back.
                            It isn't until the sun has gone down, that you come to a [b]completely[/b] exhausted stop.
                        [/p]
                        [p]
                            You slump down against a nearby tree, 
                            tightly clutching your ${global.kobold.inventory.createItemWithTooltip(new WoolSweater())} while loudly panting.
                            You missed this thing.
                            You really did.
                            You've had it for [b]years[/b].
                            It's served as a blanket, a garment and even a towel on rainy days.
                            It's the closest thing to a stuffed toy you've ever owned.
                            And with the temperature rapidly dropping, you are certain that you'll make good use of it once more, starting tonight.
                        [/p]
                        [p]
                            After taking a few more minutes to catch your breath and cuddle your sweater, you slowly rise to your feet once more.
                            You are tired.
                            [b]Very[/b] tired.
                            But you can't rest.
                            Not yet.
                            Not here.
                            It's too dangerous.
                            You take a look around.
                            You have no clue where you are.
                            All directions you gaze in look exactly the same.
                            Trees and darkness all around you.
                            You are officially [b]lost[/b].
                        [/p]
                        [p]
                            You slip on your ${global.kobold.inventory.createItemWithTooltip(new WoolSweater())}, which is slightly heated from the tender hug you gave it.
                            It fits snugly as ever, and it is bound to keep you warm throughout the night.
                            At least you won't have to worry about dying from hypothermia.
                            That just leaves about nine hundred and ninety nine other things that can kill you.
                        [/p]
                        [p]
                            Looks like you're going to have to pull an all nighter,
                            unless you can find a relatively safe place to catch some sleep in.
                            You're bound to run out of steam at some point, but that's a problem you'll face when it emerges.      
                            For now, you need to keep going.                      
                            As long as you keep heading in one direction, you'll reach the edge of the forest at one point or another, right?
                            You hope so, at least.
                        [/p]
                        [p]
                            With your body in shambles, but your spirit renewed, you begin to stride even deeper into the forest,
                            in hopes of ultimately finding your way back home, lest you [i]become[/i] one of the savages that live here, 
                            completely isolated from civilization.
                            If these woods think a little bit of sap is all it takes for you to let your guard down, they can think again.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.unknown.hasContinued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "forestUnknownBiteContinue";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.unknown.pry.bite.continued()) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.unknown.pry.bite.change();
        part += buildChoice();
        part += `<span class="todo">There is no content past this point.</span>`;
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.unknown.pry.bite.continued()) {
            return;
        }
        // REGISTER CHILDREN HERE

        if (ctrl.unknown.hasContinued()) {
            return;
        }

        // REGISTER OWN LISTENERES HERE
    };
}
