/**
 * Not barn section of the farm scene.
 * @param {BreedingFarmController} controller The breeding farm controller.
 */
function NotBarnLoot(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var downstairsId = "notBarnLootDownstairsButton";
    var upstairsId = "notBarnLootUpstairsButton";

    var toDownstairs = new NotBarnLootDownstairs(ctrl);
    var toUpstairs = new NotBarnLootUpstairs(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var dead = global.kobold.history.shared.cassidy.dead;
        var toReturn = `[p]
                            With the vixen downed, you bolt into the mansion through the open door.
                            It looks as fancy on the inside as it does on the outside.
                            The entire place is well-lit by candles in gilded candelabras.
                            Various paintings of kobolds and canines alike line the walls.
                            A myriad of luxurious cabinets and drawers clutter the broad hallway you find yourself in,
                            undoubtebly filled to the brim with [b]riches[/b].
                            Or so you imagine.
                        [/p]
                        [p]
                            Sadly, you don't have all the time in the world to strip this place of everything of value.
                            You doubt it'll be long before someone discovers Cassidy's ${dead? "corpse" : "passed out body"}.
                            The hamlet, while small, is a tight-knit community.
                            And the last thing you want to do right now is get chased down by farmers.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildDownstairsChoice() {
        var disabled = ctrl.notbarnloot.has() ? "disabled" : "";
        var isSelected = ctrl.notbarnloot.get() === NotBarnLootChoice.DOWNSTAIRS;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${downstairsId}" ${disabled}>Downstairs</button>`;
        var tooltip = global.parser.parse(`The ground floor's where the good stuff's at.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildUpstairsChoice() {
        var disabled = ctrl.notbarnloot.has() ? "disabled" : "";
        var isSelected = ctrl.notbarnloot.get() === NotBarnLootChoice.UPSTAIRS;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${upstairsId}" ${disabled}>Upstairs</button>`;
        var tooltip = global.parser.parse(`Go up to the second floor instead. There's bound to be some interesting finds there!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You loot: </div>`;
        choice += buildDownstairsChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildUpstairsChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + downstairsId), $("#" + upstairsId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerDownstairsListener() {
        $("#" + downstairsId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.notbarnloot.set(NotBarnLootChoice.DOWNSTAIRS);
            loadNextPart(toDownstairs);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerUpstairsListener() {
        $("#" + upstairsId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.notbarnloot.set(NotBarnLootChoice.UPSTAIRS);
            loadNextPart(toUpstairs);
        });
    }


    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "notBarnLoot";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.postnotbarn.get() !== NotBarnAttackChoice.LOOT) {
            return "";
        }
        global.ui.applyTheme("hamlet_mansion");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += toDownstairs.build();
        part += toUpstairs.build();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.postnotbarn.get() !== NotBarnAttackChoice.LOOT) {
            return;
        }

        toDownstairs.registerListeners();
        toUpstairs.registerListeners();

        if (ctrl.notbarnloot.has()) {
            return;
        }

        registerDownstairsListener();
        registerUpstairsListener();
    };
}

var NotBarnLootChoice = {
    DOWNSTAIRS: 1,
    UPSTAIRS: 2
};
