/**
 * Barn section of the farm scene.
 * @param {BreedingFarmController} controller The breeding farm controller.
 */
function BarnAttackLoot(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "barnAttackLootContinueButton";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var dead = global.kobold.history.shared.cassidy.dead;
        var toReturn = `[p]
                            With the vixen out of the equation, you decide to help yourself to whatever valuables you can find.
                            Sadly, judging by Cassidy's prior frantic searching through the bag of potions she ${dead ? "died" : "passed out"} near,
                            you somehow doubt there's a lot left for you to plunder.
                        [/p]`;
        if (dead) {
            toReturn += `[p]
                            Your eyes drifting towards the canine's half-nude corpse for a moment, you notice one of her hands being firmly clenched shut,
                            a very distinctive shade of pink visible through her furred fingers.
                            Reaching down, you roughly [b]pry[/b] her hand open, stealing the potion she once intended to use on you from her dead grasp.
                        [/p]
                        [p]
                            At least you won't be leaving completely empty-handed.
                            For a moment, you consider walking out the front door of the barn,
                            but it's best you [b]don't[/b] risk being seen after having committed a murder.
                            Instead, you decide to leave via the barn's shoddy back door.
                        [/p]
                        [p]
                            As you cross the table you were strapped to not a few minutes ago, you notice something small and shiny resting atop the small stool next to it.
                            Inspecting the small trinket, it appears to be the key to the veritable [b]mansion[/b] the barn is attached to.
                            You decide to pocket the key.
                            It's not like Cassidy will be needing her home anymore.
                        [/p]`;
        } else {
            toReturn += `[p]
                            You take to searching through the sack yourself.
                            It seems the canine had already removed most of the useless things from it, a myriad of empty potions cluttering the ground.
                            Still, there's plenty garbage left.
                            This must have been an entire year's supply of various nefarious concotions.
                            After a few minutes of rummaging about, you finally come across the thing she intended to addle you with:
                            a single, filled ${global.kobold.inventory.createItemWithTooltip(new FemPlus())}, which you take as your just due.
                        [/p]
                        [p]
                            At least you won't be leaving completely empty-handed.
                            For a moment, you consider walking out the front door of the barn,
                            but it's best you [b]don't[/b] risk being seen after having struck down someone who [i]is[/i] protected by law.
                            Instead, you decide to leave via the barn's shoddy back door, before she wakes up.
                        [/p]`;
        }
        
        toReturn += `   [p]
                            Exiting the barn through the back, you continue on your way to Varanar.
                            To make sure that nobody ${dead ? "" : "but the vixen herself"} can link [b]you[/b] to the events that transpired at the breeding farm,
                            you decide to take a few less-well travelled paths through various fields and a few small patches of woodland.
                            Before long, you arrive back at the eastern road to Varanar, just a few miles away from the city limits.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "barnAttackLoot";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.unawareAttack.get() !== BarnAttackChoice.LOOT) {
            return "";
        }

        global.ui.applyTheme("hamlet_day");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.unawareLoot.change();
        part += buildChoice();
        part += `<span class="todo">There is no content beyond this point.</span>`;
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.unawareAttack.get() !== BarnAttackChoice.LOOT) {
            return;
        }

        //toEager.registerListeners();

        if (ctrl.continued()) {
            return;
        }

        //registerContinueListener();
    };
}
