/**
 * Barn section of the farm scene.
 * @param {BreedingFarmController} controller The breeding farm controller.
 */
function NotBarnTeaAgree(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "notBarnTeaAgreeButton";
    
    var next = new NotBarnTeaAgreeContinue(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Yeah.
                            You can kind of see where she's coming from.
                            While you don't [i]hate[/i] your own kind, you realize that most kobolds are [i]not[/i] very good people.
                            Most of your peers are bandits, beggars, lowlives and scam artists.
                            The ones that make a living for themsevles often do so via clandestine ways.
                            And the ones that [i]don't[/i] would do [b]anything[/b] for a meal a day, let alone a roof above their heads.
                        [/p]
                        [p]
                            Cassidy seems glad you understand her position.
                            Finally managing to open the front door, she invites you into her house.
                            An invitation which you don't decline, the warmth rushing forth from her hallway seeming ever-so enticing.
                        [/p]
                        [p]
                            The vixen's mansion is as fancy on the inside as it is on the outside.
                            The entire place is well-lit by candles.
                            Various paintings of kobolds and foxes alike line the walls.
                            The canine leads you to the den, where you get to take a seat in a comfortable padded chair.
                            After a bit of smalltalk, the woman wanders into the kitchen to prepare the tea.
                            You take a moment to admire the sheer luxury you are surrounded with.
                            You've never been in a place this lavish.
                        [/p]
                        [p]
                            It is only when Cassidy returns with a pair of filled teacups and a platter full of biscuits,
                            that you stop staring at the various gold-plated items on display, you attention returning to her naked frame.
                            The vulpine hands you your tea, and then sits down ever so daintily.
                            She sips her own drink, pinky finger fully extended.
                            She'd almost be lady-like if she weren't half-naked wearing cowboy attire.
                            [i]Almost[/i].
                        [/p]
                        [p]
                            As you mutually partake in delicious, body-warming tea and crunchy, vanilla-flavored biscuits, the two of you get to chatting.
                            Topic at hand: how she came to be a [i]kobold breeder[/i].
                            Apparently, this place used to be a regular farm, until the vixen's fox-husband one day decided [i]not[/i] to come home from working the field.
                            While she doesn't know what happened to him, Cassidy assumes her other half [i]ran off[/i] to go live a better life elsewhere.
                        [/p]
                        [p]
                            Sick and tired of her own kind, unwilling to become a prostitute,
                            and unable to cultivate any meaningful amount of grain by herself,
                            the female fox turned to her most secretive of kinks.
                            The one thing that turned her on the most.
                            Something most people would ridicule her for, should they find out her deviant tastes.
                            Kobolds.
                        [/p]
                        [p]
                            She renovated the storage barn, bought her first pair of your kind from a slave trader, and the rest is history.
                            Nowadays, ontop of making a pretty penny, she has access to all the kobold sex she could ever want.
                            But she's always on the lookout for new faces.
                            That final statement is accompanied by a wink.
                            You say you're flattered, but you really don't have time to stick around.
                        [/p]
                        [p]
                            As the both of you finish your drinks, the pleasant chat winds down.
                            The canine rises from her seat, and escorts you to the door,
                            giving you one final gift before letting you go:
                            the remainder of the ${global.kobold.inventory.createItemWithTooltip(new TeaBiscuit)}s,
                            wrapped up in a neat little package.
                            You gratefully accept the present,
                            and with a smile on your face, you bid Cassidy farewell,
                            stepping back out into the cold, harsh, unforgiving world that lies outside of your new friend's luxurious home.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildContinueChoice() {
        var disabled = ctrl.postnotbarn.has() ? "disabled" : "";
        var isSelected = ctrl.postnotbarn.has();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildContinueChoice();
        choice += `</div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.postnotbarn.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "notBarnTeaAgree";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.notbarn.get() !== NotBarnTeaDoorChoice.AGREE) {
            return "";
        }
        global.ui.applyTheme("hamlet_mansion");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.teaAgreeChange();
        part += buildChoice();
        part += next.build();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.notbarn.get() !== NotBarnTeaDoorChoice.AGREE) {
            return;
        }

        next.registerListeners();

        if (ctrl.postnotbarn.has()) {
            return;
        }

        registerContinueListener();
    };
}
