/**
 * Controller for the Farmer's House scene.
 * @param {string} sceneId The id of the scene.
 */
function FarmerHouseController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var id = sceneId;
    SceneController.call(this, id);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    function postShedChange() {
        if (that.shed.get() === FarmerHouseShedChoice.NOWEAPON) {
            global.kobold.status.physical.decrease(10, "Cut by rusty metal");
            global.kobold.status.mental.decrease(10, "Beaten by garbage");
        } else {
            global.kobold.inventory.equipment.wear(new KoboldTrident());
            global.kobold.status.mental.increase(5, "Crafted weapon");
            global.kobold.status.stamina.decrease(10, "Hard work");
        }
    }

    function postShedChangeNote() {
        if (that.shed.get() === FarmerHouseShedChoice.NOWEAPON) {
            return global.ui.change.buildNotification([
                new Change("Rust-cut", "Health", -10),
                new Change("Beaten by garbage", "Sanity", -10)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Crafted", global.kobold.inventory.createItemWithTooltip(new KoboldTrident(), true), +1),
                new Change("Made something", "Sanity", +5),
                new Change("Hard work", "Stamina", -10)
            ]);
        }
    }

    function followChange() {
        global.kobold.inventory.bag.addConsumable(new Sandwich(), 2);
    }

    function followChangeNote() {
        return global.ui.change.buildNotification([
            new Change("Loot", global.kobold.inventory.createItemWithTooltip(new Sandwich(), true), +2)
        ]);
    }

    function cabinetChange() {
        if (that.cabinet.get() === FarmerHouseCabinetChoice.DRAWER) {
            global.kobold.status.mental.decrease(5, "Frustration");
            global.kobold.inventory.bag.addMisc(new CopperRing());
        } else if (that.cabinet.get() === FarmerHouseCabinetChoice.PRY) {
            global.kobold.inventory.coins += 20;
        } else {
            global.kobold.inventory.bag.addConsumable(new CouragePotion());
        }
    }

    function cabinetChangeNote() {
        if (that.cabinet.get() === FarmerHouseCabinetChoice.DRAWER) {
            return global.ui.change.buildNotification([
                new Change("Frustration", "Sanity", -5),
                new Change("Loot", global.kobold.inventory.createItemWithTooltip(new CopperRing(), true), +1)
            ]);
        } else if (that.cabinet.get() === FarmerHouseCabinetChoice.PRY) {
            return global.ui.change.buildNotification([
                new Change("Loot", "Gold", +20)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Loot", global.kobold.inventory.createItemWithTooltip(new CouragePotion(), true), +1)
            ]);
        }
    }

    function wrestleChange() {

    }

    function wrestleChangeNote() {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    }

    function wrestleLootChange() {
        // Add loot to kobold
    }

    function wrestleLootChangeNote() {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    }

    function rapeChange() {
        if (that.wrestle.has()) {
            // Wrestle rape change
        } else if (that.tied.has()) {
            // Tied up change
        } else {
            // Forced oral change
        }
    }

    function rapeChangeNote() {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    }

    function partialLootChange() {
        // Add loot to kobold
    }

    function partialLootChangeNote() {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    }

    function fullLootChange() {
        // Add loot to kobold
    }

    function fullLootChangeNote() {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.misc = new MiscController(id);
    this.arrival = new ChoiceController(id, "arrival");

    this.steal = new ChoiceController(id, "steal");
    this.shed = new ChoiceController(id, "shed");
    this.postshed = new ChangeController(id, "postshed", postShedChange, postShedChangeNote);
    this.inside = new ChoiceController(id, "inside");
    this.follow = new ChangeController(id, "follow", followChange, followChangeNote);
    this.cabinet = new ChoiceController(id, "cabinet");
    this.cabinetSteal = new ChangeController(id, "cabinetSteal", cabinetChange, cabinetChangeNote);

    this.confront = new ChoiceController(id, "confront");
    this.wrestle = new ChangeController(id, "wrestle", wrestleChange, wrestleChangeNote);
    this.choke = new ChangeController(id, "choke", wrestleLootChange, wrestleLootChangeNote);
    this.rape = new ChangeController(id, "rape", rapeChange, rapeChangeNote);
    this.scared = new ChoiceController(id, "scared");
    this.tied = new ChoiceController(id, "tied");
    this.partialLoot = new ChangeController(id, "partialLoot", partialLootChange, partialLootChangeNote);
    this.fullLoot = new ChangeController(id, "fullLoot", fullLootChange, fullLootChangeNote);


    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    this.hasRope = function () {
        global.kobold.history.setIfNotSet(id, "hasRope", global.kobold.inventory.bag.hasMisc(ItemEnum.ROPE));
        return global.kobold.history.getKey(id, "hasRope");
    };

    this.removeRope = function () {
        global.kobold.history.doIfNotSet(id, "removeRope", true, function () {
            global.kobold.inventory.bag.removeMisc(ItemEnum.ROPE);
        });
        return "";
    };

    this.intimidateFail = function () {
        global.kobold.history.doIfNotSet(id, "wrestleFail", true, function () {
            global.kobold.status.stamina.decrease(15, "Ran from farmer");
        });
        return global.ui.change.buildNotification([
            new Change("Ran", "Stamina", -15)
        ]);
    };

    this.threatenFail = function () {
        global.kobold.history.doIfNotSet(id, "wrestleFail", true, function () {
            global.kobold.status.stamina.decrease(15, "Ran from farmer");
        });
        return global.ui.change.buildNotification([
            new Change("Ran", "Stamina", -15)
        ]);
    };

    this.wrestleFail = function () {
        global.kobold.history.doIfNotSet(id, "wrestleFail", true, function () {
            global.kobold.status.stamina.decrease(15, "Ran from farmer");
        });
        return global.ui.change.buildNotification([
            new Change("Ran", "Stamina", -15)
        ]);
    };

    this.runChange = function () {
        global.kobold.history.doIfNotSet(id, "shedRun", true, function () {
            global.kobold.status.stamina.decrease(15, "Ran from farmer");
        });
        return global.ui.change.buildNotification([
            new Change("Ran", "Stamina", -15)
        ]);
    };
}

