/**
 * Arrival section of the Farmer House scene.
 * @param {BreedingFarmController} controller The Farmer House controller.
 */
function FarmerHouseArrival(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;
    
    var confrontId = arguments.callee.name + "ButtonOne";
    var stealId = arguments.callee.name + "ButtonTwo";

    var toConfront = new FarmerHouseConfront(ctrl);
    var toSteal = new FarmerHouseSteal(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You decide some good old thievery would be the best way to get over the loss of your favorite person in the entire world.
                            Your target: one of the dozen-orso homes that make up the most of the little village.
                            The farmers around these parts aren't [i]rich[/i] by any means, but the more well off amongst them aren't [i]poor[/i] either.
                            They eat what they grow, and with low rural taxes, their hard work manages to net them a decent profit.
                            Hopefully, some of that profit will soon be [i]yours[/i].
                        [/p]
                        [p]
                            You walk down the dirt road that runs through the middle of the hamlet.
                            You've stolen from here before,
                            although you hope this time [i]won't[/i] end in you being chased off by a mob of angry humans with pitchforks and torches.
                            It was late at night, so you don't think anyone'll [i]recognize[/i] you.
                            Not that there [b]is[/b] anyone present [b]to[/b] remember your face.
                            This place is a ghost town.
                            Everyone's probably off working the fields or selling their wares.
                            And that makes [b]your[/b] [i]job[/i] a whole lot easier.
                        [/p]
                        [p]
                            You take one final look around to make sure absolutely [b]no one[/b] is spying on you,
                            before casually wandering off the main road, strolling into a random farmer's back yard as though you own the place.
                            Reaching the rear-end, you turn the corner and lower your posture, dropping into a sneaking stance.
                            You take note of a small shed a bit further out back, one not unlike your [i]home[/i].
                            It doesn't look like there's anyone in it.
                            It's probably used as a storage place for farming tools.
                            Luckily enough, it blocks the view of anyone working the neighbouring potato field,
                            hiding you from the prying eyes of honest, hard-working men.
                        [/p]
                        [p]
                            The house you chose is not nearly the biggest, nor is it the most fancy.
                            In fact, it's one of the less [i]prestigious[/i] buildings in town.
                            You doubt whoever lives here is expecting to get [b]robbed[/b], which means security will be lax.
                            And indeed, testing the back door, you find the shabby, wooden thing completely unlocked!
                            The only well maintained parts of it seem to be the hinges, which function noiselessly and smoothly,
                            the door opening in complete [b]silence[/b], allowing you to slip inside in an equally quiet fashion.
                        [/p]
                        [p]
                            You find yourself in a small hallway leading into the humble household's kitchen.
                            The inside of the house is every bit as rundown as the exterior is.
                            The undecorated wooden walls look nigh-rotten.
                            You spot a [i]nasty[/i] discoloration in a particularly [i]damp[/i] ceiling-corner.
                            [b]Mold[/b].
                            Disgusting.
                            You briefly wonder how people can [i]live[/i] like this,
                            but then you remind yourself of the fact that this place is [b]several times[/b] the size of your own home.
                            Still, [i]your[/i] shack [b]doesn't[/b] have mold growing in it, despite being in the middle of the forest.
                        [/p]
                        [p]
                            The moment you were about to head deeper into the house, [b]footsteps[/b] resonate from within.
                            You freeze in place.
                            Your heart skips a beat.
                            Someone's home.
                            Flashbacks of your last [i]heist[/i] in this very hamlet shoot through your brain.
                            Your mind is torn between hiding and running, but your body ends up doing neither.
                        [/p]
                        [p]
                            While you're stuck halfway between [i]concealing yourself[/i] and [i]getting the hell out of there[/i],
                            a human saunters into the kitchen.
                            A woman.
                            You mindlessly stare at her as she turns to the small countertop dominating the cramped room,
                            and leisurely begins to slice a loaf of bread using a rusty-looking butter knife.
                            She's too engrossed in her day-to-day activities to notice you.
                            For now, at least.
                        [/p]
                        [p]
                            A mixture of relief and anxiety washes over you.
                            You haven't been caught just yet, but the presence of a housewife [i]complicates[/i] things, to say the least.
                            You need to do [i]something[/i], and you need to do it fast.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildConfrontChoice() {
        var disabled = ctrl.arrival.has() ? "disabled" : "";
        var isSelected = ctrl.arrival.get() === FarmerHouseArrivalChoice.CONFRONT;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${confrontId}" ${disabled}>Confront her</button>`;

        var tooltip = global.parser.parse(`Approach the woman. Maybe you can prevent her from screaming somehow. <span class="todo">Unavailable</span>`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 150px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildStealChoice() {
        var disabled = ctrl.arrival.has() ? "disabled" : "";
        var isSelected = ctrl.arrival.get() === FarmerHouseArrivalChoice.STEAL;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${stealId}" ${disabled}>Steal stuff</button>`;

        var tooltip = global.parser.parse(`Ignore the housewife. Do what you came here to do. You can run if she sees you. That's what you did last time.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 185px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You: </div>`;
        choice += buildConfrontChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildStealChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + confrontId), $("#" + stealId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerConfrontListener() {
        $("#" + confrontId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.arrival.set(FarmerHouseArrivalChoice.CONFRONT);
            loadNextPart(toConfront);
        });
    }
    
    /**
     * Adds a listener to the button.
     */
    function registerStealListener() {
        $("#" + stealId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.arrival.set(FarmerHouseArrivalChoice.STEAL);
            loadNextPart(toSteal);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        global.ui.applyTheme("hamlet_barn");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        part += toConfront.build();
        part += toSteal.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        toConfront.registerListeners();
        toSteal.registerListeners();

        if (ctrl.arrival.has()) {
            return;
        }

        //registerConfrontListener();
        registerStealListener();
    };
}

var FarmerHouseArrivalChoice = {
    CONFRONT: 1,
    STEAL: 2
};

