/**
 * Confront section of the Farmer House scene.
 * @param {FarmerHouseController} controller The Farmer House controller.
 */
function FarmerHouseScared(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var oralId = arguments.callee.name + "ButtonOne";
    var tieId = arguments.callee.name + "ButtonTwo";
    var lootId = arguments.callee.name + "ButtonThree";

    var toOral = new FarmerHouseForcedOral(ctrl);
    var toTie = new FarmerHouseTiedUp(ctrl);
    var toLoot = new FarmerHousePartialLoot(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Farmer house scared.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildOralChoice() {
        var disabled = ctrl.scared.has() ? "disabled" : "";
        var isSelected = ctrl.scared.get() === FarmerHouseScaredChoice.ORAL;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${oralId}" ${disabled}>Fuck her face</button>`;

        var tooltip = global.parser.parse(`Seeing the woman drop to her knees has awoken some unsavory thoughts. Act on them.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildTieChoice() {
        var hasRope = ctrl.hasRope();
        var disabled = ctrl.scared.has() || !hasRope ? "disabled" : "";
        var isSelected = ctrl.scared.get() === FarmerHouseScaredChoice.TIE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${tieId}" ${disabled}>Tie her up</button>`;

        var tooltip = global.parser.parse(`Requires a rope.`);
        if (hasRope) {
            tooltip = global.parser.parse(`You got this rope for a reason: to [s]hang yourself[/s] tie people up with.`);
        }

        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 170px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildLootChoice() {
        var disabled = ctrl.scared.has() ? "disabled" : "";
        var isSelected = ctrl.scared.get() === FarmerHouseScaredChoice.LOOT;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${lootId}" ${disabled}>Loot</button>`;

        var tooltip = global.parser.parse(`Loot as best as you can without taking your eyes off of the human.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You: </div>`;
        choice += buildOralChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildTieChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildLootChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + oralId), $("#" + lootId), $("#" + tieId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerOralListener() {
        $("#" + oralId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.scared.set(FarmerHouseScaredChoice.ORAL);
            loadNextPart(toOral);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerTieListener() {
        $("#" + tieId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.scared.set(FarmerHouseScaredChoice.TIE);
            loadNextPart(toTie);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerLootListener() {
        $("#" + lootId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.scared.set(FarmerHouseScaredChoice.LOOT);
            loadNextPart(toLoot);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        part += toOral.build();
        part += toTie.build();
        part += toLoot.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        toOral.registerListeners();
        toTie.registerListeners();
        toLoot.registerListeners();

        if (ctrl.scared.has()) {
            return;
        }

        registerOralListener();
        registerTieListener();
        registerLootListener();
    };
}

var FarmerHouseScaredChoice = {
    ORAL: 1,
    TIE: 2,
    LOOT: 3
};
