/**
 * Arrival section of the Farmer House scene.
 * @param {BreedingFarmController} controller The Farmer House controller.
 */
function FarmerHouseWrestleSuccess(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;
    
    var chokeId = arguments.callee.name + "ButtonOne";
    var rapeId = arguments.callee.name + "ButtonTwo";

    var toChoke = new FarmerHouseWrestleChoke(ctrl);
    var toRape = new FarmerHouseWrestleRape(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Wrestle success.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildChokeChoice() {
        var disabled = ctrl.wrestle.has() ? "disabled" : "";
        var isSelected = ctrl.wrestle.get() === FarmerHouseWrestleSuccessChoice.CHOKE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${chokeId}" ${disabled}>Choke her</button>`;

        var tooltip = global.parser.parse(`Knock her out so you can loot in peace.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildRapeChoice() {
        var disabled = ctrl.wrestle.has() ? "disabled" : "";
        var isSelected = ctrl.wrestle.get() === FarmerHouseWrestleSuccessChoice.RAPE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${rapeId}" ${disabled}>Rape her</button>`;

        var tooltip = global.parser.parse(`You've got her pinned down. Time to have some [i]fun[/i] with the human.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You: </div>`;
        choice += buildChokeChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildRapeChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + chokeId), $("#" + rapeId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerChokeListener() {
        $("#" + chokeId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.wrestle.set(FarmerHouseWrestleSuccessChoice.CHOKE);
            loadNextPart(toChoke);
        });
    }
    
    /**
     * Adds a listener to the button.
     */
    function registerRapeListener() {
        $("#" + rapeId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.wrestle.set(FarmerHouseWrestleSuccessChoice.RAPE);
            loadNextPart(toRape);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.wrestle.change();
        part += buildChoice();
        part += `</div>`;
        part += toChoke.build();
        part += toRape.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        toChoke.registerListeners();
        toRape.registerListeners();

        if (ctrl.wrestle.has()) {
            return;
        }

        registerChokeListener();
        registerRapeListener();
    };
}

var FarmerHouseWrestleSuccessChoice = {
    CHOKE: 1,
    RAPE: 2
};

