/**
 * Ambush section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeAmbush(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = `ambushContinueButton`;
    var toBed = new HomeAmbushToBed(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            While the odds of you taking on the oversized kobold-crossbreed in a fair fight are slim to none,
                            you figure that if you manage to sneak up behind him, you can get a critical first hit in.
                            If you can bonk his unprotected head hard enough, you might just knock him out before he knows what hit'em.
                        [/p]
                        [p]
                            You lower your posture and begin to prowl about, using the dense underbrush as concealment.
                            Sneaking around your shack in a big half-circle, you end up behind it, and more importantly: behind the debt collector.
                            You silently approach the pig-like kobold from the rear, every soft footstep bringing you closer to him.
                        [/p]
                        [p]
                            You stop just a couple of feet short of the treestump the pigbold is sitting on, 
                            intending to perform a charging, leaping bash which is sure to knock him out cold.
                            You close your eyes, and steel your nerves.`;

        var weapon = ctrl.saved.weapon();
        if (weapon) {
            toReturn += `   You ready your ${global.kobold.inventory.createItemWithTooltip(weapon)}.`;
        } else {
            toReturn += `   You ball up your hands, preparing to strike.`;
        }

        toReturn += `       Suddenly, a deep and rumbling voice snaps you out of your concentration.
                            You open your eyes, and are greeted by the sight of a scaly muscular belly protruding from below a leather chestpiece, 
                            mere inches away from your face. 
                        [/p]
                        [p]
                            [c]
                                "[color=brown]
                                    [b]Thought I didn't see you there, kid?[/b]
                                [/color]"
                            [/c]
                        [/p]
                        [p]
                            Before you have a chance to respond, the surprisingly agile and swift pig-hybrid [b]rams[/b] his powerful fist into your forehead,
                            with an immense force strong enough to send you [b]flying[/b].
                            The back of your head hits a nearby tree, nearly cracking open your skull from the rear.
                            Your brain, which was only [b]barely[/b] able to withstand the first blow, fails to wither the second impact.
                            You pass out, your lifeless body slumping to the ground.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.saved.ambush.knockContinued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.saved.ambush.knockContinue();
            loadNextPart(toBed);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeAmbush";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.saved.getApproachChoice() !== HomeSavedChoice.AMBUSH) {
            return "";
        }
        var change = ctrl.saved.ambush.knockChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += toBed.build();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.saved.getApproachChoice() !== HomeSavedChoice.AMBUSH) {
            return;
        }
        toBed.registerListeners();

        if (ctrl.saved.ambush.knockContinued()) {
            return;
        }

        registerContinueListener();
    };
}
