/**
 * Wake up section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeAmbushWakeUp(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueHamletId = `toHamletContinueButton`;
    var continueVaranarId = `toVaranarContinueButton`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Once again, you rise after a long period of slumber.
                            Your head still feels as though it was trampled on by the mounts of an entire cavalry unit,
                            but your mind is just a little more [i]clear[/i] than before.
                            Your brain has had time to recover from the two heavy blows it was forced to endure,
                            to the point where you can tolerate keeping your eyes open despite 
                            the early rays of sunlight shining through the cracks in between the wooden planks making up the walls of your shack.
                        [/p]
                        [p]
                            Sitting up straight on your [i]bed[/i], you try to recall exactly what happened.
                            One moment, you were sneaking up to a debt collector.
                            The next, he'd punched you [b]so[/b] hard he knocked you [b]the fuck[/b] out.
                            You can't quite remember [i]how[/i] you made it to your bed in between then and now, but you're glad that you did.
                        [/p]
                        [p]
                            The injury at the back of your head seems to have healed up nicely while you were unconscious.
                            It's not bleeding, not anymore, that is, and the pain has dulled to the point where you can gently touch it [b]without[/b] wincing.
                            You clean the blood off the back of your skull using a bit of straw, before getting up off of your bale of hay.
                        [/p]
                        [p]
                            With concerns over your current health slowly fading, the bigger picture of things slowly creeps to mind.
                            You're pretty sure that guy was a debt collector.
                            If he wasn't, you're fucked.
                            But you don't want to imagine that scenario right now.
                            Right now, you want to believe that despite getting seriously hurt, you managed to buy yourself a couple of days worth of time, at the very least.
                        [/p]
                        [p]
                            You stretch your limbs, and test your shaky balance.
                            It takes a few moments, but you manage to steady your posture and clear your mind.
                            You're fine.
                            Just fine.
                            Your brain wasn't hurt [i]that[/i] badly.
                            Or so you tell yourself to inspire some much-needed conviction, some [b]drive[/b] to [b]keep going[/b].
                            At least you [i]hope[/i] you didn't suffer any [i]permanent[/i] damage from this encounter.
                        [/p]
                        [p]
                            You sigh loudly.
                            The debt collector may have taken over two hundred coins, but you [b]still[/b] owe the clan another fifty orso.
                            While you [b]could[/b] do with [b]a lot[/b] more rest, you really don't want mister half-pig to pay you another visit.
                            Next time, he might outright [b]kill[/b] you instead of just knocking you out.
                        [/p]
                        [p]
                            You exit your hovel.
                            The sun is rising, and the forest is slowly coming to life, a myriad of animal noises reverberating across the woodland.
                            Realizing that you'll never be lucky enough to rob a money transport and live to tell the tale [b]a second time[/b], 
                            you decide to seek your fortune outside of the woods.
                            You can either go to Varanar directly, or you can first take a small detour to the rural hamlet just outside of town.
                            Whichever route you choose, you hope you'll end up better off than you are now.
                        [/p]`;
        
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.hasContinued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueHamletId}" ${disabled ? "disabled" : ""} style="margin: auto; float: left;">`;
        choice += `To the hamlet &gt;&gt`;
        choice += `</button>`;
        choice += `<button class="button bigbutton continuebutton" id="${continueVaranarId}" ${disabled ? "disabled" : ""} style="margin: auto; float: right;">`;
        choice += `To Varanar &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueHamletId), $("#" + continueVaranarId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }
    
    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     *  @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }
    
    /**
     * Adds a listener to the hamlet button.
     */
    function registerHamletListener() {
        $("#" + continueHamletId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.hamletSceneName, ctrl.hamletFolder);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeAmbushWakeUp";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.saved.ambush.sleepContinued()) {
            return "";
        }
        global.ui.applyTheme("home_dawn");
        var change = ctrl.saved.ambush.wakeChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += `<span class="todo">You can only go to the Hamlet.</span>`;
        part += `</div>`;

        // BUILD CHILDREN HERE

        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.saved.ambush.sleepContinued()) {
            return;
        }
        // REGISTER CHILDREN HERE

        if (ctrl.hasContinued()) {
            return;
        }

        registerHamletListener();
    };
}
